#
# spec file for package iio-sensor-proxy
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           iio-sensor-proxy
Version:        3.3
Release:        150400.9.3.1
Summary:        Proxy for IIO and input subsystems
License:        GPL-3.0-only
Group:          System/Monitoring
URL:            https://gitlab.freedesktop.org/hadess/iio-sensor-proxy
Source0:        %{url}/-/archive/%{version}/%{name}-%{version}.tar.bz2
BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.56
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gudev-1.0) >= 237
BuildRequires:  pkgconfig(systemd) >= 219
BuildRequires:  pkgconfig(udev) >= 219
Requires:       user(srvGeoClue)
%{?systemd_requires}

%description
This proxy reads sensor data from the IIO subsystem and serves to
the input subsystem

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package contains the documentation for %{name}.

%prep
%setup -q

%build
%meson -Dgtk-tests=false \
       -Dgtk_doc=true \
       -Dgeoclue-user=srvGeoClue
%meson_build

%install
%meson_install

%pre
%service_add_pre %{name}.service

%preun
%service_del_preun %{name}.service

%post
%udev_hwdb_update
%udev_rules_update
%service_add_post %{name}.service

%postun
%udev_hwdb_update
%udev_rules_update
%service_del_postun %{name}.service

%files
%{_bindir}/monitor-sensor
%{_libexecdir}/iio-sensor-proxy
%{_udevrulesdir}/*.rules
%{_unitdir}/iio-sensor-proxy.service
# Own dirs to avoid depending on dbus while building.
%dir %{_sysconfdir}/dbus-1
%dir %{_sysconfdir}/dbus-1/system.d
%config %{_sysconfdir}/dbus-1/system.d/net.hadess.SensorProxy.conf

%files doc
%{_datadir}/gtk-doc/html/%{name}/

%changelog
* Thu Sep 30 2021 badshah400@gmail.com
- Update to version 3.3:
  * Fix a bug left-over in one of the 3.2 bug fixes where some
    accelerometers would fail to initialise.
- Changes from version 3.2:
  * Fix problems parsing numbers with decimal separator.
- Require gudev >= 237 for building (for consistency with
  upstream).
- Drop the rpmlintrc file and add back appropriate service macros
  in pre/post scriptlets.
* Wed Jun 16 2021 badshah400@gmail.com
- Update to version 3.1:
  * Port to meson as a build system and add a test-suite.
  * Fix long-standing problem with property changes being sent as
    a broadcast.
  * Fix sensor support for accelerometers with different scales on
    different axes.
  * Add sensor support for RGBC light sensors.
  * Support reading proximity threshold from sysfs for DeviceTree
    devices.
- Use tar.bz2 source as this can be accessed using a repeatable
  URL (not requiring commit id).
- Switch to meson based building.
- New BuildRequires: meson (for building), gtk-doc (to generate
  docs); update required version of gudev to 234 in keeping with
  minimum required version upstream.
* Tue Jul 14 2020 bjorn.lie@gmail.com
- Update to version 3.0:
  + This release adds support for a number of sensors that didn't
    work before, usually due to being combined with other sensors
    of the same or different types (eg. dual-accelerometers,
    light/proximity combined sensors, etc.), and adds support for
    kernel-exported mount-matrix properties on Device Tree
    hardware.
  + Update URL and Source to new home on gitlab.freedesktop.org.
* Wed Sep 11 2019 badshah400@gmail.com
- Update to version 2.8:
  + Add support for accelerometers in ChromeBooks.
  + Fix screen orientation in favour of portrait when rotating
    display instead of favouring the previous orientation.
* Mon Jun 17 2019 info@ebner-markus.de
- Update to version 2.7:
  + This release fixes broken sensor readings on multiple platforms
    due to a compiler optimisation.
* Thu May 16 2019 badshah400@gmail.com
- Update to version 2.6:
  + Add support for mount matrices coming from the kernel itself,
    checking those more thoroughly for validity. On devices with
    multiple accelerometers, the ones in the base are now ignored.
  + Improve/fix support for sensors with uncommon formats.
  + Fix a couple of possible crashes and memory leaks.
- Minor specfile cleanups using spec-cleaner.
* Mon Oct 22 2018 badshah400@gmail.com
- Update to version 2.5:
  + Fix a number of build warnings and bugs.
  + Ensure some devices have non-0 update frequencies.
  + Set sensor scale to 1.0 when the device does not export one.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sun Nov  5 2017 badshah400@gmail.com
- Update to version 2.4:
  + Fix data being incorrectly read from sensors due to a naively
    broken compilation fix.
  + Support Geoclue running as a different user than "geoclue".
- Drop patches incorporated upstream:
  + 0001-data-fix-permissions-when-geoclue-runs-with-a-differ.patch
    (also drop BuildRequires on autotools and a run of autoreconf
    in the build stage that this patch necessitated).
  + iio-sensor-proxy-revert-cast-align-warnings-arm-fix.patch.
* Sat Oct 28 2017 badshah400@gmail.com
- Add iio-sensor-proxy-revert-cast-align-warnings-arm-fix.patch
  Revert "iio-buffer-utils: Fix cast-align warnings on ARM"
  because it caused rotations on all devices to have undefined
  values; patch taken from upstream (boo#1061190,
  gh#hadess/iio-sensor-proxy#191).
- Add relevant package Group for both iio-sensor-proxy
  (System/Monitor) and iio-sensor-proxy-doc (Documentation/HTML).
* Fri Sep 22 2017 fcrozat@suse.com
- Update to version 2.3:
  + Ensure API documentation is in tarball.
  + Remove workaround for long-standing kernel bug (fixed in 4.13).
  + Ignore accelerometers which are part of gaming devices.
  + Warning fixes.
- Add
  0001-data-fix-permissions-when-geoclue-runs-with-a-differ.patch:
  handle geoclue2 service running as srvGeoClue user, add
  Requires user(srvGeoClue) and add automake/ autoconf as
  BuildRequires.
- Use pregenerated API documentation and drop
  BuildRequires on gtk-doc.
* Sun Jul  9 2017 badshah400@gmail.com
- Update to version 2.2:
  + Fixes iio-sensor-proxy not receiving udev events because of
    the excessive lockdown added in version 2.1.
  + Fixes a possible crash on startup due to a race condition.
* Thu Feb  2 2017 zaitor@opensuse.org
- Update to version 2.1:
  + This release fixes a security problem that will affect services
    other than iio-sensor-proxy, that have a system D-Bus
    interface.
  + Make D-Bus policy rules only affect SensorProxy itself.
  + Lockdown service through systemd.
  + Fix startup problem on machines with a Compass device.
- Do not use systemd macros for iio-sensor-proxy.service, they are
  not designed for dbus systemd unit file.
- Add iio-sensor-proxy-rpmlintrc, silence the unwarranted rpmlint
  warnings now produced.
* Mon Dec 12 2016 zaitor@opensuse.org
- Update to version 2.0:
  + This release adds build fixes, fixes the detection of a number
    of devices that should be supported, stops trying to use
    devices that shouldn't, and adds support for the "mount-matrix"
    property, which can be used to fix the orientation of
    accelerometers on devices where the default does not work.
  + Add support for ACCEL_MOUNT_MATRIX udev property.
  + Fix startup failure on certain devices.
  + Work-around possible kernel bug on certain devices.
  + Better supported/unsupported sensors detection.
  + Better debug output.
- Drop iio-sensor-proxy-delay-starting-daemon.patch: Fixed
  upstream.
- Pass --disable-gtk-tests to configure, we do not need the sample
  programs.
* Tue Nov 22 2016 badshah400@gmail.com
- Add iio-sensor-proxy-delay-starting-daemon.patch: Add artificial
  delay before starting daemon to prevent failure to work right
  off a cold boot; patch taken from upstream git
  (gh#hadess/iio-sensor-proxy#82).
* Wed Oct 12 2016 mpluskal@suse.com
- Small packaging cleanup, add explicit pkgconfig BuildRequires.
* Mon Sep 26 2016 zaitor@opensuse.org
- Add gtk-doc BuildRequires and pass --enable-gtk-doc to configure.
  Split out a new doc subpackage.
- Stop passing --disable-silent-rules to configure and V=1 to make,
  we do debugging locally.
* Sun Sep 25 2016 badshah400@gmail.com
- Update to version 1.3:
  + Build fixes.
  + Fixes accelerometer unit scaling.
  + Really fixes regression with the IIO accelerometer in kernel
    4.8 that was supposed to be fixed in version 1.2.
* Tue Sep  6 2016 zaitor@opensuse.org
- Update to version 1.2:
  + This release mainly adds better debug output, and updated
    testing instructions in the README.
  + Fix regression with IIO accelerometer in kernel 4.8.
  + Fix possible crash in compass handling.
- Update Source Url.
* Wed Jan 20 2016 badshah400@gmail.com
- Drop rpmlintrc file; this was needed because iiio-sensor-proxy
  installs a dbus service that was so far unauthorized, but this
  has now been cleared by the Security team (bnc#939191).
* Tue Jul 28 2015 zaitor@opensuse.org
- Update to version 1.1:
  + Add support for Compasses (only accessible to GeoClue).
  + Fix service not starting in a number of cases.
  + Fix excessive CPU usage monitoring light sensors on Macs.
  + Support light sensors on some Samsung laptops.
  + Fix incorrect sensor readings on some devices due to unit
    scaling.
* Sat Jun 27 2015 zaitor@opensuse.org
- Add missing rcsymlink.
* Sat May 23 2015 crrodriguez@opensuse.org
- Update to version 1.0, this replaces udev "accelerometer"
  tool and udev rules.
* Sat Sep 27 2014 stefan.bruens@rwth-aachen.de
- initial package version
